@@ -1,6 +1,6 @@
 use strict;
 use warnings;
-package Number::Tolerant::Type 1.709;
+package Number::Tolerant::Type 1.710;
 # ABSTRACT: a type of tolerance
 
 use parent qw(Number::Tolerant);
@@ -122,7 +122,7 @@ Number::Tolerant::Type - a type of tolerance
 
 =head1 VERSION
 
-version 1.709
+version 1.710
 
 =head1 SYNOPSIS
 
@@ -190,7 +190,7 @@ When parsing "4 <= x <= 10" this regular expression is used to match the letter
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@semiotic.systems>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
