@@ -33,7 +33,7 @@ Number::Tolerant::Type::infinite - an infinite tolerance
 
 =head1 VERSION
 
-version 1.709
+version 1.710
 
 =head1 PERL VERSION
 
@@ -47,7 +47,7 @@ the minimum required perl.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@semiotic.systems>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
